# THIRD-PARTY NOTICES (Copyright & Attributions)

Copyright © 2025 Hancom, Inc. All rights reserved.

Below are copyright and notice texts for third-party libraries and components
used in this project. Full license texts are provided in the `licenses/` directory.
See also: [THIRD_PARTY_LICENSES](THIRD_PARTY_LICENSES.md) for details.

---

##### LangChain Core

###### langchain-core (`langchain-core`)
Copyright (c) LangChain, Inc.

Licensed under the MIT License.

---

##### OpenDataLoader PDF

###### opendataloader-pdf (`opendataloader-pdf`)
Copyright © 2025 Hancom, Inc. All rights reserved.

Licensed under the Apache License, Version 2.0.

Note: The `opendataloader-pdf` package bundles a Java CLI (`opendataloader-pdf-cli.jar`)
that includes additional third-party components. Those components are documented in the
`opendataloader-pdf` package's own THIRD_PARTY notices.
